---
rank: 29
title: Carrots, not sticks
date: 2016-06-23T18:27:26.605Z
layout: post
path: /carrots-not-sticks/
next: /notate-better-javascript-callstacks/
previous: /eslint-part-3-analysis/
tags:
  - nvc
  - empathy
  - ideas
  - business
  - software
---

![via https://www.flickr.com/photos/adactio/18845759/](https://static.sinap.ps/blog/2016/06_jun/carrots_not_sticks/carrots.jpg)

It may feel satisfying to use punishment to get people to do what you want. But by doing that you ignore human psychology, creating resentment which will eventually make it harder to achieve your goals. It's better to go with rewards. Carrots, not sticks, for business, personal relationships, and public policy!

<div class='fold'></div>

## Frustration

A friend came to me recently looking for advice. Knowing my history in [project management](http://scottnonnenberg.com/work/#microsoft-2010-q-3-to-2011-q-3) and [team dynamics](/from-tech-person-to-people-person/), he wanted to know how he could change the culture of his team. But that's not how he phrased it. His frustration was evident in his first question:

> _"Have you ever worked with people who just don't get it?"_

His first inclination was to put new rules in place, and then give strong negative feedback if those rules weren't followed. Maybe even fire some people! From his perspective, these rules shouldn't even be necessary. He was surprised that his people didn't seem to know what they were doing. You could tell that he thought that they deserved to pay for their mistakes.

I mentioned a few tweaks to this plan. He could make all failures public with something like an "I broke the build" hat, using community shame to change behavior. He could further enhance the social pressure by extending the negative consequences of individual failures to the entire team. He could motivate his team with sticks.

These ideas had the desired effect. We both laughed, amazed at how harsh we could theoretically be. We decided that his team would grow to hate him if he were to take the role of angry tyrant. If he really wanted to get rid of people, maybe it was the right plan!

## Compassion

Changing gears, I zeroed in on the fact that his people didn't seem to know what they were doing. First, let's understand that a little bit more:

> _"Why exactly isn't your team doing what you want them to do?_<br>
> _Do they know exactly what you want them to do?_<br>
> _Do they know how to do it?_<br>
> _If not, do they have a path to get there?"_

People naturally want to do better, but they have to know what better is. And they have to believe that a path to better is possible. I suggested trainings or pair programming, to provide both the goal and the path toward it.

> _"Do you have someone you can point to as a role model for everyone else?"_

If he had someone on the team who did have the desired traits, he could very visibly reward that person's successes. The rest of the team would then naturally gravitate towards the right behavior.

At this point I presented the opposite of the previous harsh group policies. He could put in place team-wide individual goals with positive rewards, make all successes public, and extend positive consequences to the entire team. He could motivate his team with carrots.

It seemed like a better future. We talked about the group cohesiveness he might be able to establish, the habits of continual learning and improvement embedded in the culture. You can imagine members of that team wanting to stick around for a while.

## The Difference

In one case, team members start out fearful of and frustrated with each other. In the other, they could clearly see the potential benefits of helping everyone else on the team.

Yes, [punishment can change behavior faster than reward](https://source.wustl.edu/2015/05/carrot-or-stick-punishments-may-guide-behavior-more-effectively-than-rewards/). But punishment is best at *reducing* behavior, not motivating it.

So let's think about that in relation to software. What does it really take to change your coding habits such that your submissions to the [Continuous Integration (CI)](https://en.wikipedia.org/wiki/Continuous_integration) server don't always fail the first time? Or generally have fewer bugs? Or better address customer need?

This isn't a game of [Operation](https://en.wikipedia.org/wiki/Operation_(game)). You can't just hold your arm more steadily to avoid that buzzer. You've already lost if you're trying negative motivational techniques. [Software development is complex](/the-why-of-agile/#software-development-is-complex)! Improving software skills requires focus and motivation, true engagement.

A reward incentive structure can motivate this kind of deeper change. The rewards can be extrinsic, like a bonus, team event, or even just public appreciation. But motivation is more powerful when it is intrinsic. For example, the chance to provide a material contribution to the success of the overall organization, to really make a difference to the mission, to accomplish a big goal. That's the kind of motivation that goes the distance, a positive feedback loop bringing ever greater enthusiasm and commitment.

The contrast between punishment and reward becomes clear when we consider this long perspective. Reward mechanisms, especially when they become intrinsic, can motivate for a long time. However, constant threat of negative consequences is far more likely to cause someone to be looking for a way out.

## Personal Relationships

These principles also apply outside the workplace. How often, with a romantic partner or child, do you let your frustration show with something like "you're such a slob" or "you always procrastinate!" This stick can either be a form of negative reinforcement (ceasing negative statements when you get what you want) or direct punishment (negative statements if you don't get what you want).

Both of these techniques create an environment like the dysfunctional team discussed above. If you get what you want, it won't be motivated by the right reasons. It's better to understand why something happened or didn't happen. It might feel good to express the frustration you feel, but it's unlikely to achieve your goals in the long term. Address the underlying issues, whatever they might be: unrealistic expectations, temporary distractions, low-level motivation, etc.

Again I recommend the book [Non-Violent Communication: A Language of Life](http://www.amazon.com/Nonviolent-Communication-Language-Marshall-Rosenberg/dp/1892005034). It addresses this head on. It says that most undesirable behavior is simply a case of unmet needs, even if unexpressed or lodged in the subconscious. The first step is simply understanding everyone's needs, and then you can work together towards a plan that will address all those needs.

## Public Policy

Amazingly, we can even apply these principles to large-scale public policy. For example, I like to think of capitalism as using both carrots and sticks to motivate behavior. Carrots to propel you up into stratospheric wealth. Sticks to ensure that you continue to participate in the system as a whole. The potential reward of having a private yacht, while also the potential punishment of living on the streets.

Much like my friend's initial reaction to his teammates, public policy and general sentiment towards the poor frequently has an undercurrent of the [desire to punish](http://www.theestablishment.co/2016/05/12/poor-people-deserve-to-taste-something-other-than-shame/). Why? I think it's because it is tough psychological work to justify your comfortable situation in the face of suffering. What exactly is special about what you did or what you do now? You often end up with a rough moral calculation: wealth justified by some abstract "contribution to society." Sometimes people even dare to discuss their calculation publicly: ["Do people who don't contribute to society deserve to live?"](http://intjforum.com/showthread.php?t=49626)

I've been getting more and more interested in the idea of [Universal Basic Income](https://en.wikipedia.org/wiki/Basic_income) for the past couple years. It's the idea that, instead of a complicated constellation of Federal and State agencies, each with a set of benefits, each [entangled in their own web of paperwork and rules](https://twitter.com/theMirai/status/723590018648838145), we have just one benefit. Everyone gets enough money to have a basic life: housing, food, clothes.

This would have a lot of great downstream effects, like reducing the amount of government effort spent on administration of aid programs. Reducing the size and complexity of government as a whole. Perhaps even bankrupting companies that treat their employees poorly.

But I like that it removes the stick part of our capitalist system while leaving the carrot. It would be a strong statement of the value of human life:

> _"We will support you if you don't want to participate, because we have a very high-productivity, high-technology economy with capacity to spare. If you want to participate, you can still work to get that private yacht."_

## More stick or more carrot?

Have you noticed more stick or more carrot being used around you? Do you gravitate towards the stick more often than the carrot? Try a bit more carrot! I'd love to hear how things go!

Always remember the role of [the larger system](/systems-and-incentives/) in driving behavior. The amount of change you can personally motivate in others is usually a whole lot smaller than you expect. Manage your frustration by setting realistic expectations.

Good luck!

---

* Authentic motivation
  * "Purpose, mastery, and autonomy" http://www.ted.com/talks/dan_pink_on_motivation
  * What 'great leaders' do to inspire action https://www.ted.com/talks/simon_sinek_how_great_leaders_inspire_action
  * A good summary of some of the major theories on motivation https://www.mindtools.com/pages/article/motivating-your-team.htm
* Studies on punishment vs. reward:
  * "Performance improved substantially more when the feedback was positive" for younger children: https://www.psychologytoday.com/blog/family-affair/200809/rewards-are-better-punishment-here-s-why
  * Punishment changes behavior more quickly, but changes don't stick: http://www.bulletproofmusician.com/reward-vs-punishment-which-results-in-better-learning/
* The types of behavioral conditioning:
  * http://www.simplypsychology.org/operant-conditioning.html
  * https://en.wikipedia.org/wiki/Reinforcement
* Universal Basic Income:
  * https://medium.com/@2noame/why-should-we-support-the-idea-of-an-unconditional-basic-income-8a2680c73dd3
  * http://fivethirtyeight.com/features/universal-basic-income/
  * http://www.theguardian.com/politics/2016/apr/13/should-we-scrap-benefits-and-pay-everyone-100-a-week-whether-they-work-or-not
  * http://www.theatlantic.com/politics/archive/2014/08/why-arent-reformicons-pushing-a-guaranteed-basic-income/375600/
  * http://www.vox.com/2016/6/1/11827024/universal-basic-income
  * Motivated by technology advancements:
    * https://medium.com/basic-income/deep-learning-is-going-to-teach-us-all-the-lesson-of-our-lives-jobs-are-for-machines-7c6442e37a49
    * http://simulacrum.cc/2013/07/10/three-trends-that-push-us-towards-an-unconditional-basic-income/
  * Organizations testing it:
    * https://www.givedirectly.org/basic-income
    * Ycombinator:
      * http://blog.ycombinator.com/basic-income
      * https://blog.ycombinator.com/moving-forward-on-basic-income
  * Countries considering tests:
    * http://usuncut.com/world/finland-plans-to-pay-everyone-in-the-country-876-a-month/
    * http://metro.co.uk/2016/03/25/japan-is-considering-giving-away-free-money-5774687/

